@@ -3,7 +3,7 @@ package Net::FullAuto::ISets::Local::Chaining_is;
 ### OPEN SOURCE LICENSE - GNU AFFERO PUBLIC LICENSE Version 3.0 #######
 #
 #    Net::FullAuto - Powerful Network Process Automation Software
-#    Copyright © 2000-2015  Brian M. Kelly
+#    Copyright © 2000-2016  Brian M. Kelly
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as
@@ -1499,10 +1499,12 @@ END
    $ad='encoding: utf8';
    ($stdout,$stderr)=$handle->cmd(
       "sed -i \'/default_view/a $ad\' myapp.yml");
+print "GOING TO START MYAPP SERVER\n";
    $handle->{_cmd_handle}->print(
       'script/myapp_server.pl --background');
    ($stdout,$stderr)=$handle->cwd("../AdventREST");
    ($stdout,$stderr)=$handle->cmd("${sudo}ldconfig");
+print "GOING TO START WEB SERVER\n";
    $handle->{_cmd_handle}->print(
       "${sudo}script/adventrest_server.pl -p 3001 &");
    $prompt=substr($handle->{_cmd_handle}->prompt(),1,-1);
@@ -1537,7 +1539,7 @@ END
           |_| \_|\___|\__|     |_|   \__,_|_|_/_/   \_\__,_|\__\___/ ©
 
 
-   Copyright © 2000-2015  Brian M. Kelly  Brian.Kelly@FullAuto.com
+   Copyright © 2000-2016  Brian M. Kelly  Brian.Kelly@FullAuto.com
 
 END
    eval {
